@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '0.04';
+our $VERSION = '0.041';
 
 use Carp (); # for default fail handler
 use Exporter ();
@@ -66,7 +66,7 @@ Data::Util - A selection of utilities for data and data types
 
 =head1 VERSION
 
-This document describes Data::Util version 0.04
+This document describes Data::Util version 0.041
 
 =head1 SYNOPSIS
 
@@ -101,9 +101,15 @@ This document describes Data::Util version 0.04
 	use Data::Util qw(anon_scalar)
 
 	my $ref_to_undef = anon_scalar();
-
 	$x = anon_scalar($x); # OK
 
+	# to display a value for error messages
+	use Data::Util qw(neat);
+	print neat("foo\n");   # => "foo\n"
+	print neat(42);        # => 42
+	print neat(undef);     # => undef
+	print neat([1, 2, 3]); # => [1, ...]
+
 
 =head1 DESCRIPTION
 
@@ -114,7 +120,7 @@ This module provides utility subroutines for data and data types.
 =head2 Check functions
 
 Check functions are introduced by the C<:check> tag, which check the argument
-type.
+type and return a bool.
 
 These functions also checks overloading magic, e.g. C<${}> for a SCALAR reference.
 
@@ -149,7 +155,7 @@ For a regular expression reference.
 For an instance of a class.
 
 It is equivalent to something like
-C<Scalar::Util::blessed($x) && $x->isa($class) ? $x : undef>,
+C<Scalar::Util::blessed($x) && $x->isa($class)>,
 but significantly faster and easy to use.
 
 =back
@@ -157,16 +163,15 @@ but significantly faster and easy to use.
 
 =head2 Validating functions
 
-Validating functions are introduced by the C<:validate> tag, and returns the
-first argument C<$x>.
+Validating functions are introduced by the C<:validate> tag which check the
+argument and returns the first argument C<$x>.
 These are like the C<:check> functions but dies if the argument type
-is not the wanted type.
+is invalid.
 
 These functions also checks overloading magic, e.g. C<${}> for a SCALAR reference.
 
 =over 4
 
-
 =item scalar_ref($x)
 
 For a SCALAR reference.
@@ -193,7 +198,7 @@ For a regular expression reference.
 
 =item instance($x, $class)
 
-For an instance of a class.
+For an instance of a I<$class>.
 
 =back
 
@@ -215,7 +220,8 @@ Returns a neat string that is suitable to display.
 
 =item get_stash(package_name)
 
-Returns the symbol table hash (also known as B<stash>) of I<package_name>.
+Returns the symbol table hash (also known as B<stash>) of I<package_name>
+if the stash exists.
 
 It is similar to C<< do{ no strict 'refs'; \%{$package_name . '::'} } >>,
 but does B<not> create the stash if I<package_name> does not exist.
@@ -252,9 +258,7 @@ Perl 5.8.1 or later, and a C compiler.
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<bug-scalar-util-ref@rt.cpan.org/>, or through the web interface at
-L<http://rt.cpan.org/>.
+Please report any bugs or feature requests to the author.
 
 =head1 SEE ALSO
 
